<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">
  
  <!-- top level template to do some checking and setup etc -->
  <xsl:template name="root">
    <xsl:param name="title">
      <xsl:text>ABRS Flora of Australia Online Search Results</xsl:text>
    </xsl:param>
    
    <html>
      <head>
        <xsl:choose>
          <xsl:when test="descendant::xsql-error">
            <title>Database Error</title>
          </xsl:when>
          <xsl:otherwise>
            <title><xsl:value-of select="$title"/></title>
          </xsl:otherwise>
        </xsl:choose>
        <link href="css/abifflora.css" rel="stylesheet" type="text/css"/>
        <xsl:call-template name="extraheader"/>
      </head>
      <body bgcolor="#FFFFFF">

        <xsl:choose>
          <xsl:when test="descendant::xsql-error">
            <xsl:apply-templates select="descendant::xsql-error"/>
          </xsl:when>
          <xsl:when test="count(//rowset/row) = 0 and count(//ROWSET/ROW) = 0">
            <xsl:call-template name="nodata">
              <xsl:with-param name="title" select="$title"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates/>
          </xsl:otherwise>
        </xsl:choose>
      </body>
    </html>
  </xsl:template>


  <!-- template to call when we have no data. This just augments
       nodata, as defined in common-html. -->

  <!-- Greg July 2003 says this template nodata-addendum needs to be added into the common-html.xsl
       even though it is at the bottom of the nameslist.xsl.
  -->

  <xsl:template name="nodata-addendum">
    <xsl:if test="/nameslist/request/parameters/sort_by = 'a.sn_taxon_name' or /nameslist/request/session/sort_by = 'a.sn_taxon_name'">
      <p>Only names which have ranks family, genus, species,
      subspecies, variety or form appear in the Hierarchical Names
      List Display with the sort order as Alphabetical. By clicking on
      the button below, you will automatically search again with the
      sort order "As in the published volumes".</p>
      <!-- note we have to send this back to redirect.jsp, as that page sets 
           up session variables etc. -->
      <form action="redirect.jsp" method="post">
        <input type="hidden" name="sort_by" value="a.pnid"/>
        <xsl:for-each select="/nameslist/request/parameters/*[name() != 'sort_by' and name() != 'refine']">
          <input type="hidden" name="{name()}" value="{.}"/>
        </xsl:for-each>
        <xsl:for-each select="/nameslist/request/session/*[name() != 'sort_by']">
          <input type="hidden" name="{name()}" value="{.}"/>
        </xsl:for-each>
        <!-- we have to add this kludge here so that redirect.jsp
             doesn't chuck a wobbly. -->
        <xsl:if test="/nameslist/request/parameters/pnid">
          <input type="hidden" name="displaytype" value="NamesList"/>
          <input type="hidden" name="sn_infsprnk" value="%"/>
        </xsl:if>

        <input type="submit" name="search" value="Search Again"/>
      </form>
    </xsl:if>
  </xsl:template>

  <!-- template to apply in the case of an
       xsql error -->
  <xsl:template match="xsql-error">
    <h1>Database Error</h1>
    <p>
      A database error occurred. Please try again later.
    </p>
    <xsl:if test="$debug">
      <h2>Error Message</h2>
      <xsl:element name="pre">
        <xsl:value-of select="message"/>
      </xsl:element>
      <h2>Database Statement</h2>
      <xsl:element name="pre">
        <xsl:value-of select="statement"/>
      </xsl:element>
    </xsl:if>
  </xsl:template>

  <!-- template to apply in the case of no
       data returned -->
  <xsl:template name="nodata">
    <xsl:param name="title">Flora of Australia Online Search Results</xsl:param>
    <h1><xsl:value-of select="$title"/></h1>
    <p>Your query returned no data.</p>

    <!-- Robyn 29th July changed the Published link to be the online-resources one. -->
    <xsl:if test= "//request/session/volslist = &quot;NOT IN (''lichenchecklist'', ''49'', ''50'')&quot;" >
      <p>Check the family of the plant name you are searching for
      has been <a href="http://www.deh.gov.au/biodiversity/abrs/online-resources/flora/main/published.html">
      published</a> by the Australian Biological
      Resources Study. If you have selected a Limit Display Results
      field, the field you have chosen may not be available.</p>
    </xsl:if>

    <xsl:if test= "//request/session/volslist = &quot;= ''49''&quot;" >
      <p>Check the family of the plant name you are searching for
      has been <a href="http://www.deh.gov.au/biodiversity/abrs/online-resources/flora/49/published.html">
      published</a> by the Australian Biological
      Resources Study. If you have selected a Limit Display Results
      field, the field you have chosen may not be available.</p>
    </xsl:if>

    <xsl:if test= "//request/session/volslist = &quot;= ''50''&quot;" >
      <p>Check the family of the plant name you are searching for
      has been <a href="http://www.deh.gov.au/biodiversity/abrs/online-resources/flora/50/published.html">
      published</a> by the Australian Biological
      Resources Study. If you have selected a Limit Display Results
      field, the field you have chosen may not be available.</p>
    </xsl:if>
   
    <!-- this allows each page to add their own data to the nodata template -->
    <xsl:call-template name="nodata-addendum"/>

    <!-- Old way commented out.
    <p>Please
      <a href="xxx-query-styles.html">return to the search screen</a> 
      and try again.
    </p>
    -->

    <!-- Robyn 11th July - replaced New Search based on what Volume is in the session.
         Found it best to insert quotes for enclosing a string, within a string to use &quot;
         as the enclosing quotes.

         Could try setting a variable and see how this goes.
         Not sure how to test this template for 'nodata' so just used the generic bit of
         //request/session/volslist which has been the same for all the *.xsl pages so far.
    -->
    <xsl:if test= "//request/session/volslist = &quot;NOT IN (''lichenchecklist'', ''49'', ''50'')&quot;" >
      <p>Please <a href="main-query-styles.html">return to the search screen</a>
      and try again.</p>
    </xsl:if>

    <xsl:if test= "//request/session/volslist = &quot;= ''49''&quot;" >
      <p>Please <a href="vol49-query-styles.html">return to the search screen</a>
      and try again.</p>
    </xsl:if>

    <xsl:if test= "//request/session/volslist = &quot;= ''50''&quot;" >
      <p>Please <a href="vol50-query-styles.html">return to the search screen</a>
       and try again.</p>
    </xsl:if>

  </xsl:template>

  <!-- This template formats the given text appropriately for the rank.
       This allows us to format name parts consistently where the
       formatting gets broken up over the name parts. E.g. for
       infraspecies, the infraspecies has formatForRank(parent) rank
       formatForRank(name). -->
  <xsl:template name="formatForRank">
    <xsl:param name="text"/>
    <xsl:param name="rank"/>
    <xsl:param name="status"/>

    <xsl:choose>
      <!-- Robyn 11th July - allow Status doubtful to be done as well. 
           Need to work on this more next week, to make sure doubtful names are italic.

           Robyn 14th July, Helen wants everything bold except for Status doubtful.
      Old code shown:
      <xsl:when test="($rank='subg.' or
                      $rank='sp.' or
                      $rank='subsp.' or
                      $rank='var.' or
                      $rank='f.' or
                      $rank='sect.' or
                      $rank='subsect.' or
                      $rank='ser.' or
                      $rank='subser.') and (not($status) or $status != 'doubtful')">
      -->

      <xsl:when test="(not($status) or $status != 'doubtful')">
        <b><xsl:value-of select="$text"/></b>
      </xsl:when>
      <xsl:otherwise>
        <i><xsl:value-of select="$text"/></i>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Template to format the name for the Standard Flora Display -->
  <!-- or the Simple Names List. Assumes that the calling template -->
  <!-- has occurred within the context of a ROW element, or something similar. -->
  <xsl:template name="standardDisplayName">
    <!-- if format-family has a value, then we should format the
         family as we would format any name. We need this as the
         standard flora display doesn't want to format the name,
         whereas the simple names list does. 
         -->
    <xsl:param name="format-family"/>

    <xsl:if test="RANK='trib.' or RANK='subfam.' or RANK='subtrib.'">
      <xsl:call-template name="formatForRank">
        <xsl:with-param name="text" select="FAMILY"/>
        <xsl:with-param name="rank" select="RANK"/>
        <xsl:with-param name="status" select="STATUS"/>
      </xsl:call-template>
      <xsl:text>&nbsp;</xsl:text>
      <xsl:value-of select="RANK"/>
      <xsl:text>&nbsp;</xsl:text>
    </xsl:if>

    <!-- have to do one thing for hybrids, another thing for other name types -->
    <!-- Robyn ask Helen more about how to do doubtful names properly. -->
         
    <!-- also do doubtful names differently -->

    <!-- Robyn 10th July 2003, looks like need to change common-html.xsl
         and the stddisplay.xsl for the changes to get imported, in the session. -->
    <!-- Will change the NAME to NAME_HYBRID in the code below.  -->

    <xsl:choose>
      <xsl:when test="NAME_KIND = 'hybrid_formula'">
        <xsl:call-template name="formatForRank">
          <xsl:with-param name="text">
            <xsl:value-of select="NAME_HYBRID"/>
            <xsl:text> &#215; </xsl:text>
            <xsl:call-template name="strip-genus-from-hybrid-name">
              <xsl:with-param name="genus" select="GENUS"/>
              <xsl:with-param name="hybrid-name">
                <xsl:value-of select="NAME_HYBRID2"/>
              </xsl:with-param>
            </xsl:call-template>
          </xsl:with-param>
          <xsl:with-param name="rank" select="RANK"/>
          <xsl:with-param name="status" select="STATUS"/>
        </xsl:call-template>
      </xsl:when>

      <xsl:when test="NAME_KIND = 'hybrid_formula_?'">
        <xsl:call-template name="formatForRank">
          <xsl:with-param name="text">
            <xsl:value-of select="NAME_HYBRID"/>
            <xsl:text> &#215; ?</xsl:text>
            <xsl:call-template name="strip-genus-from-hybrid-name">
              <xsl:with-param name="genus" select="GENUS"/>
              <xsl:with-param name="hybrid-name">
                <xsl:value-of select="NAME_HYBRID2"/>
              </xsl:with-param>
            </xsl:call-template>
          </xsl:with-param>
          <xsl:with-param name="rank" select="RANK"/>
          <xsl:with-param name="status" select="STATUS"/>
        </xsl:call-template>
      </xsl:when>

      <!-- Robyn 11th July. Not sure, why doesn't the otherwise cater for it.
      <xsl:when test="STATUS = 'doubtful'">
        <xsl:call-template name="formatForRank">
          <xsl:with-param name="text">

            <xsl:value-of select="NAME_HYBRID"/>

          </xsl:with-param>

          <xsl:with-param name="rank" select="RANK"/>
          <xsl:with-param name="status" select="STATUS"/>
        </xsl:call-template>
      </xsl:when>
      -->

      <xsl:otherwise>
       <!-- Robyn. 11th July -->
        <xsl:if test="RANK='sect.' or RANK='subsect.' or RANK='ser.' or RANK='subser.' or RANK='subg.'">
          <xsl:value-of select="NAME_SYMBOL"/>
          <xsl:call-template name="formatForRank">
            <xsl:with-param name="text">
              <xsl:choose>
                <xsl:when test="GENUS[@NULL]">
                  <xsl:value-of select="PARENT"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="GENUS"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="rank" select="RANK"/>
            <xsl:with-param name="status" select="STATUS"/>
          </xsl:call-template>
      
          <xsl:text>&nbsp;</xsl:text>
          
          <xsl:if test="not(AUTHOR_AUTONYM[@NULL])">
            <xsl:value-of select="AUTHOR_AUTONYM" disable-output-escaping="yes"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>
          <xsl:value-of select="RANK"/>
          <xsl:text>&nbsp;</xsl:text>
        </xsl:if>
    
        <xsl:if test="RANK='sp.'">
          <!-- Robyn 11th July 2003.  Used to debug the value of Status. 
          <h1>About to call the formatForRank for sp.
            <xsl:value-of select="STATUS"/>
          </h1>
          -->

          <xsl:call-template name="formatForRank">
            <xsl:with-param name="text">
              <xsl:value-of select="NAME_SYMBOL[not(@NULL)]"/>
              <xsl:value-of select="GENUS"/>
            </xsl:with-param>
            <xsl:with-param name="rank" select="RANK"/>
            <xsl:with-param name="status" select="STATUS"/>
          </xsl:call-template>
          <xsl:text>&nbsp;</xsl:text>
        </xsl:if>

        <xsl:if test="RANK='formtaxon'">
          <!-- Robyn 12th January 2004.  Used to debug the value of Status. 
          <h1>About to call the formatForRank for formtaxon
            <xsl:value-of select="STATUS"/>
          </h1>
  
          Had to remove
          <xsl:value-of select="RANK"/>
          as the rank now is 'formtaxon'
          -->

          <xsl:call-template name="formatForRank">
            <xsl:with-param name="text">
              <xsl:value-of select="NAME_SYMBOL[not(@NULL)]"/>
              <xsl:value-of select="GENUS"/>
            </xsl:with-param>
            <xsl:with-param name="rank" select="RANK"/>
            <xsl:with-param name="status" select="STATUS"/>
          </xsl:call-template>
          <xsl:text>&nbsp;</xsl:text>
          <xsl:text>form taxon</xsl:text>
          <xsl:text>&nbsp;</xsl:text>  
        </xsl:if>
           
        <xsl:if test="RANK='var.' or RANK='f.' or RANK='subsp.'">
          <xsl:call-template name="formatForRank">
            <xsl:with-param name="text">
              <xsl:value-of select="NAME_SYMBOL"/>
              <xsl:value-of select="PARENT"/>
            </xsl:with-param>
            <xsl:with-param name="rank" select="RANK"/>
            <xsl:with-param name="status" select="STATUS"/>
          </xsl:call-template>
                  
          <xsl:text>&nbsp;</xsl:text>
          <xsl:if test="not(AUTHOR_AUTONYM[@NULL])">
            <xsl:value-of select="AUTHOR_AUTONYM" disable-output-escaping="yes"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>
          <xsl:value-of select="RANK"/>
          <xsl:text>&nbsp;</xsl:text>
        </xsl:if>
            
        <xsl:if test="NAME_KIND = 'named_hybrid'">
          <xsl:text>&#215;</xsl:text>
        </xsl:if>

        <xsl:if test="QUALIFIER[not(@NULL)]">
          <xsl:choose>
            <xsl:when test="STATUS = 'doubtful'">
              <i><xsl:value-of select="QUALIFIER[not(@NULL)]"/></i>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="QUALIFIER[not(@NULL)]"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:text>&nbsp;</xsl:text>
        </xsl:if>

        <xsl:if test="NAME and not(NAME[@NULL]) and (RANK != 'fam.' or $format-family) and RANK != 'group' and RANK != 'subgroup'">
          <xsl:call-template name="formatForRank">
            <xsl:with-param name="text" select="NAME"/>
            <xsl:with-param name="rank" select="RANK"/>
            <xsl:with-param name="status" select="STATUS"/>
          </xsl:call-template>
        </xsl:if>
    
        <xsl:if test="RANK = 'group' or RANK = 'subgroup'">
          <xsl:call-template name="formatForRank">
            <xsl:with-param name="text">
              <xsl:value-of select="TAXON_NAME"/>
              <xsl:if test="GENUS[not(@NULL)]">
                <xsl:text> (</xsl:text>
                <xsl:value-of select="GENUS[not(@NULL)]"/>
                <xsl:text>)</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="rank" select="RANK"/>
            <xsl:with-param name="status" select="STATUS"/>
          </xsl:call-template>
        </xsl:if>
        
      </xsl:otherwise>
    </xsl:choose>
            
    <xsl:if test="AUTHOR and not(AUTHOR[@NULL])">
      <xsl:text>&nbsp;</xsl:text>
      <xsl:value-of select="AUTHOR" disable-output-escaping="yes"/>
    </xsl:if>
    <xsl:if test="AUTHOR_IN and not(AUTHOR_IN[@NULL])">
      <xsl:text>,&nbsp;</xsl:text>
      <i>in</i>
      <xsl:text>&nbsp;</xsl:text>
      <xsl:value-of select="AUTHOR_IN" disable-output-escaping="yes"/>
    </xsl:if>
    
    <xsl:if test="NAME_NOTE and not(NAME_NOTE[@NULL])">
      <xsl:text>,&nbsp;</xsl:text>
      <xsl:value-of select="NAME_NOTE" disable-output-escaping="yes"/>
    </xsl:if>
    
    <xsl:if test="$protologue">
      <xsl:if test="PROTO_REF and not(PROTO_REF[@NULL])">
        <xsl:text>,&nbsp;</xsl:text>
        <xsl:value-of select="PROTO_REF" disable-output-escaping="yes"/>
      </xsl:if>
              
      <xsl:if test="PROTO_DATE and not(PROTO_DATE[@NULL])">
        <xsl:text>&nbsp;(</xsl:text>
        <xsl:value-of select="PROTO_DATE" disable-output-escaping="yes"/>
        <xsl:text>)</xsl:text>
      </xsl:if>
    </xsl:if>
            
    <xsl:if test="NAME_AS and not(NAME_AS[@NULL])">
      <xsl:text>, as </xsl:text>
      <xsl:value-of select="NAME_AS" disable-output-escaping="yes"/>
    </xsl:if>
            
    <xsl:if test="$protologue">
      <xsl:if test="PROTO_NAME_AS and not(PROTO_NAME_AS[@NULL])">
        <xsl:text>, as </xsl:text>
        <xsl:value-of select="PROTO_NAME_AS" disable-output-escaping="yes"/>
      </xsl:if>
          
      <xsl:if test="PROTO_NOTE and not(PROTO_NOTE[@NULL])">
        
        <!-- R. Lawrence 23rd August 2004.  Added to stop a dummy proto_note for Volume 0
        printing ',' for the Families.  Don't explicitly test for VOLUME ='0' however! -->        

        <xsl:if test="(RANK != 'fam.' or $format-family) and RANK != 'group' and RANK != 'subgroup'" >
          <xsl:text>,&nbsp;</xsl:text>
        </xsl:if>

        <xsl:value-of select="PROTO_NOTE" disable-output-escaping="yes"/>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!--
       Template to strip the genus from the given name.
       Use this in the keys so that e.g. "Genname aus x Genname bus"
       becomes "aus x bus".
       -->
  <xsl:template name="strip-genus-from-hybrid-name">
    <xsl:param name="genus"/>
    <xsl:param name="hybrid-name"/>
    <xsl:choose>
      <xsl:when test="starts-with($hybrid-name, $genus)">
        <xsl:value-of select="normalize-space(substring-after($hybrid-name, $genus))"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$hybrid-name"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
