<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

  <!-- stylesheet to create an HTML page for the images -->
  <!-- this stylesheet assumes that the SQL query will only ever return
       a single row. -->

  <xsl:output method="html"/>
  <xsl:template match="/page">
    <html>
      <head>
        <title>Image Display</title>
      </head>
      <body bgcolor="#FFFFFF">
        <!-- store the image url in a variable for use later -->
        <xsl:variable name="imgsrc">
          <xsl:text>images/vol</xsl:text>
          <xsl:value-of select="//request/parameters/volume"/>
          <xsl:text>/</xsl:text>
          <xsl:value-of select="//request/parameters/imgurl"/>          
        </xsl:variable>

        <xsl:if test="rowset/row/imgkind = 'map'">
          <xsl:call-template name="map">
            <xsl:with-param name="imgsrc" select="$imgsrc"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="rowset/row/imgkind = 'fig'">
          <xsl:call-template name="fig">
            <xsl:with-param name="imgsrc" select="$imgsrc"/>
          </xsl:call-template>
        </xsl:if>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="request"/>

  <xsl:template name="map">
    <xsl:param name="imgsrc"/>

    <p align="center">
      <img src="{$imgsrc}" alt="Map {rowset/row/imgtext}"/>
    </p>
    <p align="center">
      <xsl:choose>
        <xsl:when test="//request/parameters/maptext">
          <xsl:value-of select="//request/parameters/maptext"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>Map </xsl:text>
          <xsl:value-of select="rowset/row/imgtext"/>
        </xsl:otherwise>
      </xsl:choose>
    </p>
    <p align="center" style="font-size: smaller">
      &#x00a9; Commonwealth of Australia
    </p>
  </xsl:template>

  <xsl:template name="fig">
    <xsl:param name="imgsrc"/>

    <!-- text to go in the first paragraph block -->
    <xsl:variable name="capone">
      <xsl:value-of select="rowset/row/fig_caption" disable-output-escaping="yes"/>
      <!-- xsl:if test="rowset/row/fig_scale_status != 'silent'" -->
      <xsl:text> </xsl:text>
      <xsl:value-of select="rowset/row/fig_scale" disable-output-escaping="yes"/>
      <!-- /xsl:if -->
      <xsl:text> </xsl:text>
      <xsl:value-of select="rowset/row/fig_illustrator" disable-output-escaping="yes"/>
    </xsl:variable>

    <!-- text to go in the second paragraph block -->
    <xsl:variable name="captwo">
      <xsl:value-of select="rowset/row/fig_title" disable-output-escaping="yes"/>
      <xsl:text> figure </xsl:text>
      <xsl:value-of select="rowset/row/fig_number" disable-output-escaping="yes"/>
      <xsl:text>.</xsl:text>
    </xsl:variable>

    <p>
      <img src="{$imgsrc}" alt="Image {rowset/row/fig_number}" align="left" style="margin-right: 3em"/>
      <xsl:value-of select="$capone" disable-output-escaping="yes"/>
    </p>

    <!-- should only bother with another paragraph if we have one to put in -->
    <xsl:if test="$captwo != ' figure .'">
      <p>
        <xsl:value-of select="$captwo" disable-output-escaping="yes"/>
      </p>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
