<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

  <!-- import the generic stuff -->
  <xsl:import href="common-html.xsl"/>
  <xsl:import href="variables.xsl"/>

  <xsl:output method="html"/>

  <xsl:variable name="title">
    <xsl:text>ABRS Flora of Australia Online Names List</xsl:text>
  </xsl:variable>

  <!-- extra headers. empty at the moment -->
  <xsl:template name="extraheader">
    <xsl:text> </xsl:text>
  </xsl:template>

  <!-- top level stuff -->
  <xsl:template match="/">
    <xsl:call-template name="root">
      <xsl:with-param name="title">
        <xsl:value-of select="$title"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <!-- This template checks the number of rowset elements
       returned as children of the nameslist element, and
       decides whether to format the names as a multiple 
       list or as a hierarchical list (if only a single
       top level rowset exists). This works as the 
       stored procedure NamesList.GetNames() will return
       differing numbers of rows depending on how many
       matches occur. See that function for more info.
       -->
  <xsl:template match="nameslist">
    <!-- check for multiple matches -->

    <!-- Robyn 10th July 2003.  Don't need the hybridcount anymore. -->
    <!--
    <xsl:variable name="hybridcount">
      <xsl:choose>
        <xsl:when test="/nameslist/request/parameters/pnid">
          <xsl:value-of select="number('0')"/>
        </xsl:when>
        <xsl:otherwise>
	-->
          <!-- Robyn 9th July 2003.  The name_kind can be 'hybrid_formula', 'hybrid_formula_?' or
               'named_hybrid', which should all have the status of 'hybrid' -->
          <!--<xsl:value-of select="number(count(rowset/row[child::name_kind = 'hybrid_formula']))"/>-->
          <!--
	  <xsl:value-of select="number(count(rowset/row[child::name_kind]))"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    -->

    <xsl:variable name="namescount">
      <xsl:choose>
        <xsl:when test="/nameslist/request/parameters/pnid">
          <xsl:value-of select="number('1')"/>
        </xsl:when>
        <xsl:otherwise>
          <!-- Robyn 9th July 2003.  The name_kind can be 'hybrid_formula', 'hybrid_formula_?' or
               'named_hybrid', which should all have the status of 'hybrid' -->
          <!--<xsl:value-of select="number(count(rowset/row[count(child::name_kind) = 0 or child::name_kind != 'hybrid_formula']))"/>-->
          <!--<xsl:value-of select="number(count(rowset/row[count(child::name_kind) = 0]))"/>-->
          <xsl:value-of select="number(count(rowset/row))"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <!-- Robyn 9th July 2003, the sum of hybridcount and namescount is to be greater than 1.-->
    <!--<xsl:if test="($hybridcount + $namescount ) &gt; 1">-->
    <xsl:if test="$namescount &gt; 1">
      <h1><xsl:value-of select="$title"/></h1>
      <!-- do the non hybrid names first -->
      <!-- Robyn 9th July 2003, This has been changed to include hybrid ones as well,
           hence the commenting out of the test for namescount. -->

      <!--<xsl:if test="$namescount &gt; 1">-->
      <p>Click a name to see the names list for that taxon.</p>
      <p>
        <xsl:apply-templates select="rowset/row" mode="name"/>
      </p>
      <!--</xsl:if>-->

      <!-- Helen doesn't want to see the Hybrid formula anymore, as it is included in
        the above mode="name" template. 
        So Robyn will comment out the Hybrid Formula 
      -->
      <!-- now do the hybrid names -->
      <!--
      <xsl:if test="$hybridcount &gt; 0">
        <xsl:variable name="sing_or_plur">
          <xsl:choose>
            <xsl:when test="$hybridcount &gt; 1">
              <xsl:text>ae</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>a</xsl:text>
            </xsl:otherwise>
          </xsl:choose>          
        </xsl:variable>
        <xsl:if test="$namescount &gt; 1">
          <hr/>
        </xsl:if>
        <h2>Hybrid Formul<xsl:value-of select="$sing_or_plur"/></h2>
        <p>Your search returned the following hybrid formul<xsl:value-of select="$sing_or_plur"/>. Names
        list details aren't available for hybrid formulae, but you can see the
        treatment by selecting the appropriate name.</p>
        <p>
          <xsl:apply-templates select="rowset/row[child::name_kind = 'hybrid_formula']" mode="hybrid"/>
        </p>
      </xsl:if> 
      -->
      <!-- End of doing the hybrid names -->

    </xsl:if>

    <!-- check for a single match -->
    <!-- Robyn 9th July 2003, either hybridcount or namescount can be 1, but not both. -->
    <!--<xsl:if test="($hybridcount + $namescount ) = 1">-->
    <xsl:if test="$namescount = 1">

      <h1>Flora of Australia Online Names List</h1>
      <xsl:apply-templates select="rowset" mode="single"/>
    </xsl:if>

    <!-- new search at the end of the page -->
    <!-- Robyn 10th July - replaced New Search based on what Volume is in the session.
         Found it best to insert quotes for enclosing a string, within a string to use &quot;
         as the enclosing quotes.

         Could try setting a variable and see how this goes.
    -->
    <xsl:if test= "/nameslist/request/session/volslist = &quot;NOT IN (''lichenchecklist'', ''49'', ''50'')&quot;" >
      <hr/>
      <p align="left"><a href="main-query-styles.html">New Search</a></p>
    </xsl:if>

    <xsl:if test= "/nameslist/request/session/volslist = &quot;= ''49''&quot;" >
      <hr/>
      <p align="left"><a href="vol49-query-styles.html">New Search</a></p>
    </xsl:if>

    <xsl:if test= "/nameslist/request/session/volslist = &quot;= ''50''&quot;" >
      <hr/>
      <p align="left"><a href="vol50-query-styles.html">New Search</a></p>
    </xsl:if>

    <!-- Old way, commented out. 
    <hr/>
    <p>
      <a href="xxx-query-styles.html">New Search</a>
    </p>
    -->
  </xsl:template>

  <!-- ************************************************** -->
  <!--   Templates for displaying multiple results        -->
  <!-- ************************************************** -->

  <!-- Robyn 9th July 2003.  Hybrid template not used anymore.
  -->
  <!-- Displays a name for a hybrid element -->
  <xsl:template match="row" mode="hybrid">
    <xsl:element name="a">
      <xsl:attribute name="href">
        <xsl:text>stddisplay.xsql?pnid=</xsl:text>
        <xsl:value-of select="pnid"/>
      </xsl:attribute>
      <xsl:value-of select="name"/>
      <xsl:text> &#215; </xsl:text>
      <xsl:choose>
        <xsl:when test="name_kind = 'hybrid_formula_?'">
          <xsl:text>?</xsl:text>
          <!-- no need for an if test here - if it doesn't exist it won't print -->
          <xsl:call-template name="strip-genus-from-hybrid-name">
            <xsl:with-param name="genus" select="genus"/>
            <xsl:with-param name="hybrid-name" select="name_hybrid2"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="name_kind = 'hybrid_formula'">
          <xsl:call-template name="strip-genus-from-hybrid-name">
            <xsl:with-param name="genus" select="genus"/>
            <xsl:with-param name="hybrid-name" select="name_hybrid2"/>
          </xsl:call-template>
        </xsl:when>
      </xsl:choose>
    </xsl:element>

    <!-- add a linebreak for all but the last element -->
    <xsl:if test="count(following-sibling::row[position() = 1]) > 0">
      <br/>
    </xsl:if>
  </xsl:template>

  <!-- Displays a non hybrid name -->
  <xsl:template match="row" mode="name">
    <xsl:element name="a">
      <xsl:attribute name="href">
        <xsl:text>nameslist.xsql?pnid=</xsl:text>
        <xsl:value-of select="pnid"/>
      </xsl:attribute>
      
      <xsl:call-template name="buildName"/>

    </xsl:element>

    <!-- add a linebreak for all but the last element -->
    <xsl:if test="count(following-sibling::row[position() = 1]) > 0">
      <br/>
    </xsl:if>
  </xsl:template>

  <!-- ************************************************** -->
  <!--  Templates for displaying single result            -->
  <!--  hierarchically.                                   -->
  <!-- ************************************************** -->

  <!-- starts a list when it sees the top-level rowset element -->
  <xsl:template match="rowset" mode="single">
    <ul>
      <xsl:apply-templates mode="single"/>
    </ul>
  </xsl:template>
  
  <!-- starts a list for the children elements found -->
  <xsl:template match="children">
    <ul>
      <xsl:apply-templates/>
    </ul>
  </xsl:template>

  <!-- the ROW and CHILDREN_ROW should behave identically, so
       just call the generic "aname" template 
       -->
  <xsl:template match="row" mode="single">
    <xsl:call-template name="aname">
      <xsl:with-param name="name">
        <xsl:call-template name="buildName"/>
      </xsl:with-param>
      <xsl:with-param name="id" select="pnid"/>
      <xsl:with-param name="rank" select="rank"/>
      <xsl:with-param name="title" select="title"/>
      <xsl:with-param name="status" select="status"/>
    </xsl:call-template>
    <xsl:apply-templates select="children"/>
  </xsl:template>

  <xsl:template match="children_row">
    <xsl:call-template name="aname">
      <xsl:with-param name="name">
        <xsl:call-template name="buildName"/>
      </xsl:with-param>
      <xsl:with-param name="id" select="pnid"/>
      <xsl:with-param name="rank" select="rank"/>
      <xsl:with-param name="title" select="title"/>
      <xsl:with-param name="status" select="status"/>
   </xsl:call-template>
    <xsl:apply-templates select="children"/>
  </xsl:template>

  <xsl:template name="buildName">
    <xsl:variable name="builtname">
      <xsl:choose>
        <xsl:when test="name_kind = 'hybrid_formula_?'">
          <!-- Robyn 9th July 2003.  The Hybrid's first name now use
          name_hybrid field.
          -->
          <!--<xsl:value-of select="name"/>-->
          <xsl:value-of select="name_hybrid"/>
          <xsl:text> &#215; ?</xsl:text>
          <xsl:call-template name="strip-genus-from-hybrid-name">
            <xsl:with-param name="genus" select="genus"/>
            <xsl:with-param name="hybrid-name" select="name_hybrid2"/>
          </xsl:call-template>
        </xsl:when>

        <xsl:when test="name_kind = 'hybrid_formula'">
          <!-- Robyn 9th July 2003.  The Hybrid's first name now use
          name_hybrid field.
          -->
          <!--<xsl:value-of select="name"/>-->
          <xsl:value-of select="name_hybrid"/>
          <xsl:text> &#215; </xsl:text>
          <xsl:call-template name="strip-genus-from-hybrid-name">
            <xsl:with-param name="genus" select="genus"/>
            <xsl:with-param name="hybrid-name" select="name_hybrid2"/>
          </xsl:call-template>
        </xsl:when>

        <xsl:otherwise>
          <xsl:choose>

            <!-- precede the name with the family and the rank -->
            <!-- Robyn 7th August 2003.  Helen doesn't want the subfam. ones
            to have the Family in front of them.  
            WBSC84: Will leave the code in case she changes her mind.

            <xsl:when test="rank='subfam.'">
              <xsl:value-of select="family"/>
              <xsl:text>&nbsp;</xsl:text>
              <xsl:value-of select="rank"/>
              <xsl:text>&nbsp;</xsl:text>
            </xsl:when>
            -->

            <!-- precede the name with the rank -->
            <!-- Robyn 5th August 2003.  Helen says we do not need to precede the 
            order or class with its rank.  In fact these ranks will not have a names field 
            only title.  So removed order and class from the following test
            -->
            <xsl:when test="rank='trib.' or rank='subfam.' or rank='subtrib.' or rank = 'subg.' 
            or rank = 'ser.' or rank = 'subser.' or rank = 'sect.' or rank = 'subsect.' ">
              <xsl:value-of select="rank"/>
              <xsl:text>&nbsp;</xsl:text>
            </xsl:when>
      
            <!-- preced the name with the genus -->
            <xsl:when test="rank='sp.' or rank='formtaxon'">
              <xsl:value-of select="genus"/>
              <xsl:text>&nbsp;</xsl:text>
            </xsl:when>
      
            <!-- precede name with parent -->
            <xsl:when test="rank='var.' or rank='f.' or rank='subsp.'">
              <xsl:value-of select="parent"/>
              <xsl:text>&nbsp;</xsl:text>
              <xsl:value-of select="rank"/>
              <xsl:text>&nbsp;</xsl:text>
            </xsl:when>

          </xsl:choose>

          <xsl:if test="name_kind = 'named_hybrid'">
            <xsl:text>&#215;</xsl:text>
          </xsl:if>

          <xsl:if test="qualifier">
            <xsl:value-of select="qualifier"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>

          <xsl:value-of select="name" disable-output-escaping="yes"/>

          <!-- special cases for group and subgroup -->
          <xsl:if test="rank = 'group'">
            <xsl:text> Group</xsl:text>
          </xsl:if>
          <xsl:if test="rank = 'subgroup'">
            <xsl:text> Subgroup</xsl:text>
          </xsl:if>
          
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:if test="status = 'doubtful'">
      <i><xsl:copy-of select="$builtname"/></i>
    </xsl:if>
    <xsl:if test="not(status) or status != 'doubtful'">
      <xsl:copy-of select="$builtname"/>
    </xsl:if>

  </xsl:template>

  <!-- template to display a single name in the hierarchical list.
       Called aname as it displays the details for 'a name'.
       -->
  <xsl:template name="aname">
    <xsl:param name="name"/>
    <xsl:param name="id"/>
    <xsl:param name="rank" value="foo"/>
    <xsl:param name="title"/>
    <xsl:param name="status"/>
    <li>

      <xsl:element name="a">
        <xsl:attribute name="href">
          <xsl:text>nameslist.xsql?pnid=</xsl:text>
          <xsl:value-of select="$id"/>
        </xsl:attribute>

        <xsl:element name="img">
          <xsl:attribute name="src">
            <xsl:text>icons/</xsl:text>
            <xsl:choose>
              <xsl:when test="$status = 'hybrid'">
                <xsl:text>hybrid.png</xsl:text>
              </xsl:when>
              <xsl:when test="$status = 'doubtful' or not($rank)">
                <xsl:text>doubtful.png</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="concat(translate($rank, '.', ''), '.png')"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:attribute name="alt">
            <xsl:value-of select="$rank"/>
          </xsl:attribute>
        </xsl:element>

      </xsl:element>

      <xsl:text> </xsl:text>
      <xsl:element name="a">
        <!-- print the title if the name doesn't exist -->
        <xsl:attribute name="href">stddisplay.xsql?pnid=<xsl:value-of select="$id"/></xsl:attribute>

        <!-- Robyn 9th July 2003.  In the hierarchical names list, do the 
             hybrid_formula fields differently.
        -->
        <xsl:choose>
          <xsl:when test="$name and ($name != '')">
            <xsl:choose>
              <xsl:when test="name_kind = 'hybrid_formula_?'">
                <xsl:value-of select="name_hybrid"/>
                  <xsl:text> &#215; ?</xsl:text>
                  <xsl:call-template name="strip-genus-from-hybrid-name">
                    <xsl:with-param name="genus" select="genus"/>
                    <xsl:with-param name="hybrid-name" select="name_hybrid2"/>
                  </xsl:call-template>
              </xsl:when>

              <xsl:when test="name_kind = 'hybrid_formula'">
                <xsl:value-of select="name_hybrid"/>
                <xsl:text> &#215; </xsl:text>
                <xsl:call-template name="strip-genus-from-hybrid-name">
                  <xsl:with-param name="genus" select="genus"/>
                  <xsl:with-param name="hybrid-name" select="name_hybrid2"/>
                </xsl:call-template>
              </xsl:when>

              <xsl:otherwise>
                <xsl:copy-of select="$name" disable-output-escaping="yes"/>
              </xsl:otherwise>
            </xsl:choose>

          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$title"/>
          </xsl:otherwise>
        </xsl:choose>

      </xsl:element>
    </li>
  </xsl:template>

  <!-- template to call when we have no data. This just augments
       nodata, as defined in common-html. -->
  <xsl:template name="nodata-addendum">
    <xsl:if test="/nameslist/request/parameters/sort_by = 'a.sn_taxon_name' or /nameslist/request/session/sort_by = 'a.sn_taxon_name'">
      <p>Only names which have ranks family, genus, species,
      subspecies, variety or form appear in the Hierarchical Names
      List Display with the sort order as Alphabetical. By clicking on
      the button below, you will automatically search again with the
      sort order "As in the published volumes".</p>
      <!-- note we have to send this back to redirect.jsp, as that page sets 
           up session variables etc. -->
      <form action="redirect.jsp" method="post">
        <input type="hidden" name="sort_by" value="a.pnid"/>
        <xsl:for-each select="/nameslist/request/parameters/*[name() != 'sort_by' and name() != 'refine']">
          <input type="hidden" name="{name()}" value="{.}"/>
        </xsl:for-each>
        <xsl:for-each select="/nameslist/request/session/*[name() != 'sort_by']">
          <input type="hidden" name="{name()}" value="{.}"/>
        </xsl:for-each>

        <!-- we have to add this kludge here so that redirect.jsp
             doesn't chuck a wobbly. -->
        <xsl:if test="/nameslist/request/parameters/pnid">
          <input type="hidden" name="displaytype" value="NamesList"/>
          <input type="hidden" name="sn_infsprnk" value="%"/>
        </xsl:if>

        <input type="submit" name="search" value="Search Again"/>
      </form>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
