<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:import href="common-html.xsl"/>
  <xsl:import href="variables.xsl"/>

  <xsl:output method="html" encoding="iso-8859-1"/>

  <xsl:variable name="OutputFormat">
    <xsl:value-of select="./request/parameters/FORMAT"/>
  </xsl:variable>

  <!-- set up a key so that we can get a unique source field -->
  <!-- c.f. Muenchian Technique -->
  <!-- Robyn 7th August 2003.  Copied the code from stddisplay.xsl to 
  put the "source" at the bottom. -->
  <xsl:key name="source_key" match="SOURCE" use="."/>

  <!-- these variables represent whether or not the user
       wishes to display certain fields. We do the tests
       here and store them in variables to remove some
       clutter from the style sheet below.
       -->
  <!-- assume that if no session variables exist then we should
       display everything - the user has probably been given a
       URL and just followed, so would not have come in by the
       initial search page. 
       -->
  <xsl:variable name="displayall" select="not(//request/session/displayfields) or //request/session/displayfields = 'all'"/>

  <xsl:variable name="chromosomes" select="boolean($displayall or //df_chromosomes)"/>
  <xsl:variable name="commonnames" select="boolean($displayall or //df_commonnames)"/>
  <xsl:variable name="conservationstatus" select="boolean($displayall or //df_conservationstatus)"/>
  <xsl:variable name="description" select="boolean($displayall or //df_description)"/>
  <xsl:variable name="distribution" select="boolean($displayall or //df_distribution)"/>
  <xsl:variable name="phenology" select="boolean($displayall or //df_phenology)"/>
  <xsl:variable name="taxrefs" select="boolean($displayall or //df_taxrefs)"/>
  <xsl:variable name="habitat" select="boolean($displayall or //df_habitat)"/>
  <xsl:variable name="images" select="boolean($displayall or //df_images)"/>
  <xsl:variable name="notes" select="boolean($displayall or //df_notes)"/>
  <xsl:variable name="illrefs" select="boolean($displayall or //df_illrefs)"/>
  <xsl:variable name="typification" select="boolean($displayall or //df_typification)"/>
  <xsl:variable name="keys" select="boolean($displayall or //df_keys)"/>
  <xsl:variable name="protologue" select="boolean($displayall or //df_protologue)"/>
  <xsl:variable name="synonymy" select="boolean($displayall or //df_synonymy)"/>
  <xsl:variable name="specimens" select="boolean($displayall or //df_specimens)"/>

  <!-- template to insert the extra header information -->
  <xsl:template name="extraheader">
    <style type="text/css">
      h3.title { text-align: center; font-weight: bold;}
      a.small { font-size: 80% }
      a.smaller { font-size: 70% }
      p.form { text-align: center }
      p.right { text-align: right }
      p.left { text-align: left }
      /* body { font-size: 8pt } */
      p.contributor { display: block; font-style:italic; text-align: center }
      p.address { display: block; text-align: center; font-size: 70%; }
      p.name { display: block; text-align: left; margin-top: 2em; }
      p.cname { display: block; font-weight: bold; text-align: center; margin-top: 2em; }
      p.protologue { display: inline; text-align: left; font-weight: normal }
      p.typification { display: block; text-align: left }
      p.synonymy { display: block; text-align: left }
      p.illustrations { display: block; text-align: left }
      p.distribution { display: block; text-align: left }
      p.commonname { display: inline; text-align: left }
      p.notes { display: block; text-align: left }
      p.figure { display: inline; text-align: left }
      p.maps { display: inline; text-align: left }
      p.description { display: block; text-align: left }
      p.specimens { display: block; text-align: left }
      p.etymology { display: block; text-align: left }
      p.reference { display: block; text-align: left }
      p.habitat { display: block; text-align: left }
      p.standard { display: block; text-align: left }
      p.key  { font-size: 70% }
      p.key-point  { font-size: 70%; text-align: left; }
      p.key-leaf {font-size: 70%; font-weight: bold; text-align: right;}
      hr.indented-key  { float: none; }
      h1.name { text-align: left; }
      h2.key { text-align: center; font-size: 70%; font-stle: bold;}
      table.key { width: 95%; align: center }
      td.key-point { font-size: 70%; width: 70% }
      td.key-leaf { font-size: 70%; text-align: right; text-weight: bold; }
      p.nameslistlink { text-align: left; font-size: 70% }
      p.source { font-size: 80%; color: #2A8E32 }
    </style>    
  </xsl:template>

  <xsl:template match="/">
    <xsl:call-template name="root"/>
  </xsl:template>

  <!-- main template -->
  <xsl:template match="page">
    <table width="100%" border="1" align="center" cellspacing="0" height="490">
      <tr>
        <td rowspan="8" height="231" width="8%" valign="top">
          <p class="form">
            <form action="stddisplay.xsql" method="post">Quick search<br/>(1 word):
            <input type="text" size="10" value="{/page/request/parameters/find}" name="taxon_name"/><br/>
            <input type="submit" value="Submit"/>
          </form></p>

          <!-- Old code commented out.
          <p align="left"><a class="small" href="xxx-query-styles.html">New Search</a></p>
          -->

          <!-- Robyn 10th July - replaced New Search based on what Volume is in the session.
             Found it best to insert quotes for enclosing a string, within a string to use &quot;
             as the enclosing quotes.

             Could try setting a variable and see how this goes.
          -->
      
          <xsl:if test= "/page/request/session/volslist = &quot;NOT IN (''lichenchecklist'', ''49'', ''50'')&quot;" >
            <p align="left"><a class="small" href="main-query-styles.html">New Search</a></p>
          </xsl:if>

          <xsl:if test= "/page/request/session/volslist = &quot;= ''49''&quot;" >
            <p align="left"><a class="small" href="vol49-query-styles.html">New Search</a></p>
          </xsl:if>

          <xsl:if test= "/page/request/session/volslist = &quot;= ''50''&quot;" >
            <p align="left"><a class="small" href="vol50-query-styles.html">New Search</a></p>
          </xsl:if>

          <p align="left">&nbsp;</p>

          <!-- Robyn 29th July removed Links down the side of the page.
          <p align="left">&nbsp;</p>
          <p align="left"><a class="smaller" href="http://www.deh.gov.au/biodiversity/abrs/about/publications/glossaries/index.html">ABRS Glossaries</a></p>
          <p align="left"><a class="smaller" href="http://www.anbg.gov.au/cgi-bin/apni">APNI</a> </p>
          <p align="left"><a class="smaller" href="http://www.deh.gov.au/biodiversity/abrs/flora/links.html#amani">AMANI</a></p>
          <p align="left"><a class="smaller" href="http://plantnet.rbgsyd.gov.au/PlantNet/fwalgae/index.htm">Freshwater Algae</a></p>
          <p align="left"><a class="smaller" href="http://www.rbgmelb.org.au/fungi/">Fungi</a></p>
          <p align="left"><a class="smaller" href="http://www.anbg.gov.au/abrs/lichenlist/introduction.html">Lichens</a></p>
          <p align="left"><a class="smaller" href="http://www.anbg.gov.au/win">What's its Name?</a></p>
          <p><a href="http://www.deh.gov.au/biodiversity/abrs/index.html"><img src="images/abrsgrn_transp.gif" width="56" height="92" border="0" vspace="0" hspace="0"/></a></p>
          <p><a href="http://www.deh.gov.au/biodiversity/abrs/flora/index.html"><img width="56" height="60" border="0" vspace="0" hspace="0" src="images/abif_small_transp.gif"/></a></p>
          <p>&nbsp;</p>
          -->
        </td>
        <td width="88%" height="476" valign="top">
          <div align="center">
            <h1>Flora of Australia Online</h1>
    
            <!-- header //-->
      
            <xsl:if test="$OutputFormat='HTML'">
              format
            </xsl:if>
      
            <xsl:for-each select="ROWSET/ROW">
              <p class="name">
                <!-- families behave in a slightly different manner than 
                     in the standard flora display. So we have to do it by hand.
                     -->
                <xsl:call-template name="standardDisplayName">
                  <xsl:with-param name="format-family" select="'yes'"/>
                </xsl:call-template>
              </p>

              <!-- names list link -->
              <p class="nameslistlink">
                <xsl:element name="a">
                  <xsl:attribute name="href">
                    <xsl:text>nameslist.xsql?pnid=</xsl:text>
                    <xsl:value-of select="PNID"/>
                  </xsl:attribute>
                  <xsl:text>Hierarchical Names List Entry</xsl:text>
                </xsl:element>
                <xsl:text>&nbsp;</xsl:text>
                <xsl:element name="a">
                  <xsl:attribute name="href">
                    <xsl:text>stddisplay.xsql?pnid=</xsl:text>
                    <xsl:value-of select="PNID"/>
                  </xsl:attribute>
                  <xsl:attribute name="style">
                    <xsl:text>margin-left: 3em</xsl:text>
                  </xsl:attribute>
                  <xsl:text>Standard Flora Display</xsl:text>
                </xsl:element>
              </p>
          
            </xsl:for-each>      
    
            <!-- tail -->

          </div>
        </td>
        <td rowspan="2" height="231" width="4%">&nbsp;</td>
      </tr>
      
      <!-- Robyn 7th August 2003.  Copied the code from stddisplay.xsl to 
      put the "source" at the bottom. -->

      <tr>
        <td width="88%" height="2">
          <div align="center">

            <!--  Old way commented out.
            <font color="#2A8E32" size="-1"><i>Data derived from </i>
            Flora of Australia vol. 16 (1995): 
            <i>a product of ABRS. &#169; Commonwealth of Australia</i></font>
            -->

           <!-- use Muenchian Technique to get unique source values -->
           <xsl:for-each select=".//SOURCE[generate-id(.) = generate-id(key('source_key', .))]">
             <p class="source"><xsl:value-of select="." disable-output-escaping="yes"/></p>
           </xsl:for-each>
          </div>
        </td>
      </tr>

    </table>
  </xsl:template>
</xsl:stylesheet>