<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:import href="common-html.xsl"/>
  <xsl:import href="variables.xsl"/>

  <!-- Robyn 10th July - changed temporarily for common-html.xsl.  -->

  <xsl:output method="html" encoding="utf-8"/>

  <xsl:variable name="OutputFormat">
    <xsl:value-of select="./request/parameters/FORMAT"/>
  </xsl:variable>

  <!-- set up a key so that we can get a unique source field -->
  <!-- c.f. Muenchian Technique -->
  <xsl:key name="source_key" match="SOURCE" use="."/>

  <!-- these variables represent whether or not the user
       wishes to display certain fields. We do the tests
       here and store them in variables to remove some
       clutter from the style sheet below.
       -->

  <!-- assume that if no session variables exist then we should
       display everything - the user has probably been given a
       URL and just followed, so would not have come in by the
       initial search page. 
       -->
  <xsl:variable name="numdfs" select="count(/page/request/parameters/*[self::df_chromosomes or self::df_commonnames or self::df_conservationstatus or self::df_description or self::df_distribution or self::df_phenology or self::df_taxrefs or self::df_habitat or self::df_images or self::df_notes or self::df_illrefs or self::df_typification or self::df_keys or self::df_synonymy or self::df_specimens])"/>

  <xsl:variable name="displayall" select="boolean($numdfs = 0 or $numdfs = 15)"/>

  <xsl:variable name="chromosomes" select="boolean($displayall or /page/request/parameters/df_chromosomes)"/>
  <xsl:variable name="commonnames" select="boolean($displayall or /page/request/parameters/df_commonnames)"/>
  <xsl:variable name="conservationstatus" select="boolean($displayall or /page/request/parameters/df_conservationstatus)"/>
  <xsl:variable name="description" select="boolean($displayall or /page/request/parameters/df_description)"/>
  <xsl:variable name="distribution" select="boolean($displayall or /page/request/parameters/df_distribution)"/>
  <xsl:variable name="phenology" select="boolean($displayall or /page/request/parameters/df_phenology)"/>
  <xsl:variable name="taxrefs" select="boolean($displayall or /page/request/parameters/df_taxrefs)"/>
  <xsl:variable name="habitat" select="boolean($displayall or /page/request/parameters/df_habitat)"/>
  <xsl:variable name="images" select="boolean($displayall or /page/request/parameters/df_images)"/>
  <xsl:variable name="notes" select="boolean($displayall or /page/request/parameters/df_notes)"/>
  <xsl:variable name="illrefs" select="boolean($displayall or /page/request/parameters/df_illrefs)"/>
  <xsl:variable name="typification" select="boolean($displayall or /page/request/parameters/df_typification)"/>
  <xsl:variable name="keys" select="boolean($displayall or /page/request/parameters/df_keys)"/>
  <xsl:variable name="protologue" select="'true'"/>
  <xsl:variable name="synonymy" select="boolean($displayall or /page/request/parameters/df_synonymy)"/>
  <xsl:variable name="specimens" select="boolean($displayall or /page/request/parameters/df_specimens)"/>

  <!-- Template to insert the extra header information -->
  <xsl:template name="extraheader">
    <style type="text/css">
      h3.title { text-align: center; font-weight: bold;}
      .small { font-size: 80% }
      a.smaller { font-size: 70% }
      p.form { text-align: center }
      p.right { text-align: right }
      p.left { text-align: left }
      /*      body { font-size: 8pt } */
      p.contributor { display: block; font-style:italic; text-align: center }
      p.contributor_sp { display: block; font-style:italic; text-align: left }
      p.address { display: block; text-align: center; font-size: 70%; }
      p.name { display: block; text-align: left; margin-top: 2em; }
      p.cname { display: block; font-weight: bold; text-align: center; margin-top: 2em; }
      p.protologue { display: inline; text-align: left; font-weight: normal }
      p.typification { font-size: 80%; display: block; text-align: left }
      p.synonymy { font-size: 80%; display: block; text-align: left }
      p.illustrations { font-size: 80%; display: block; text-align: left }
      p.distribution { display: block; text-align: left }
      p.commonname { display: inline; text-align: left }
      p.notes { display: block; text-align: left }
      p.figure { display: inline; text-align: left }
      p.maps { display: inline; text-align: left }
      p.description { display: block; text-align: left }
      p.specimens { font-size: 80%; display: block; text-align: left }
      p.etymology { display: block; text-align: left }
      p.reference { display: block; text-align: left }
      p.habitat { display: block; text-align: left }
      p.standard { display: block; text-align: left }
      hr.indented-key  { float: none; }
      h1.name { text-align: left; }

       /* p.key  { font-size: 70% } */
      p.key-leaf { font-size: 80%; font-weight: bold; text-align: right; }
      h2.key { text-align: center; font-size: 70%; font-stle: bold;}
      table.key { font-size: 80%; width: 100%; align: center }
      /*      td.key-leaf { font-size: 70%; text-align: right; text-weight: bold; } */
      /* td.key_id { font-size: 80% } */
      .key-rank { font-weight: normal }

      p.nameslistlink { text-align: left; font-size: 70% }
      /* 'data derived from...' text */
      .source { font-size: 80%; color: #2A8E32 }
    </style>
    <!-- debugging information -->
    <meta name="numdfs" value="{$numdfs}"/>
    <meta name="displayall" value="{$displayall}"/>
  </xsl:template>

  <!-- notes get printed at least twice, so use a template rather
       than a for-each tag -->
  <xsl:template match="NOTES_ITEM">
    <p class="notes">
      <xsl:value-of select="NOTE" disable-output-escaping="yes"/>
    </p>
  </xsl:template>

  <xsl:template match="SYNONYMS_ITEM">
    <xsl:if test="not(SYNCIT[@NULL]) or not (SYNTYPE[@NULL])">
      <p class="synonymy">
        <xsl:value-of select="SYNCIT" disable-output-escaping="yes"/>
        <xsl:text>&nbsp;</xsl:text>
        <xsl:value-of select="SYNTYPE" disable-output-escaping="yes"/>
      </p>
    </xsl:if>
  </xsl:template>

  <!-- can use the same template for images and maps. So may as well -->
  <xsl:template match="IMAGES_ITEM">
    <xsl:param name="maptext">
      <xsl:text>Map </xsl:text>
      <xsl:value-of select="IMGTEXT"/>
    </xsl:param>

    <!-- link to the image -->
    <xsl:variable name="href">
      <xsl:text>image.xsql?</xsl:text>
      <xsl:text>pnid=</xsl:text>
      <xsl:value-of select="../../PNID"/>
      <xsl:text>&amp;volume=</xsl:text>
      <xsl:value-of select="../../VOLUME"/>
      <xsl:text>&amp;imgurl=</xsl:text>
      <xsl:value-of select="IMGURL" disable-output-escaping="yes"/>
      <xsl:if test="IMGKIND='map'">
        <xsl:text>&amp;maptext=</xsl:text>
        <xsl:value-of select="$maptext"/>
      </xsl:if>
    </xsl:variable>

    <!-- text to display for each link -->
    <xsl:variable name="disptext">
      <xsl:value-of select="IMGTEXT" disable-output-escaping="yes"/>
    </xsl:variable>

    <!-- have an opening space - we assume that a leading "Fig." or "Map" has gone in -->
    <xsl:text> </xsl:text>

    <!-- only display the figure link when we have permission -->
    <xsl:choose>
      <xsl:when test="FIG_PERMISSION[@NULL] or FIG_PERMISSION = 'yes'">
        <xsl:element name="a">
          <xsl:attribute name="href">
            <xsl:value-of select="$href"/>
          </xsl:attribute>
          <xsl:attribute name="onclick">
            <xsl:text>w=window.open('</xsl:text>
            <xsl:value-of select="$href"/>
            <xsl:if test="IMGKIND='fig'">
              <xsl:text>','figWindow','height=555,width=600,top=50,left=120,alwaysRaised=1,resizable'); return false</xsl:text>
            </xsl:if>
            <xsl:if test="IMGKIND='map'">
              <xsl:text>','mapWindow','height=425,width=360,top=50,left=120,alwaysRaised=1,resizable'); return false</xsl:text>
            </xsl:if>
          </xsl:attribute>
          <xsl:value-of select="$disptext"/>
        </xsl:element>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$disptext"/>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:choose>
      <xsl:when test="position() != last()">
        <xsl:text>,</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>.</xsl:text>
      </xsl:otherwise>
    </xsl:choose>  
  </xsl:template>

  <!-- template for contributors, key contributors -->
  <!-- Robyn Lawrence 23/12/2003 - changed for the lower ranked contributors
       to be displayed in brackets.  -->
  <xsl:template match="CONTRIBUTORS_ITEM|KEY_CONTRIBUTORS_ITEM">

    <xsl:if test="position() = 1 and
           ( ../../RANK ='var.' or ../../RANK ='f.' or
             ../../RANK ='subsp.' or ../../RANK ='sp.')">
      <xsl:text>(</xsl:text>
    </xsl:if>

    <xsl:value-of select="CONTRIBUTOR" disable-output-escaping="yes"/>
    <xsl:if test="NOTES[not(@NULL)]">
      <xsl:text>&nbsp;(</xsl:text>
      <xsl:value-of select="NOTES" disable-output-escaping="yes"/>
      <xsl:text>)</xsl:text>
    </xsl:if>
    <xsl:if test="position() != last()">
      <xsl:text>, </xsl:text>
    </xsl:if>

    <xsl:if test="position() = last() and
           ( ../../RANK ='var.' or ../../RANK ='f.' or
             ../../RANK ='subsp.' or ../../RANK ='sp.')">
      <xsl:text>)</xsl:text>
    </xsl:if>

  </xsl:template>

  <xsl:template match="/">
    <xsl:call-template name="root"/>
  </xsl:template>

  <!-- main template -->
  <xsl:template match="page">
    <table width="100%" border="1" align="center" cellspacing="0" height="490">
      <tr>
      <!-- Robyn 12th August commenting out height
      <td rowspan="2" height="231" width="8%" valign="top">-->

      <td rowspan="8" width="8%" valign="top">
      <p class="form">
      <form action="stddisplay.xsql" method="post">Quick search (1 word):<br/>
        <input type="text" size="10" value="{/page/request/parameters/find}" name="taxon_name"/><br/>
        <input type="submit" value="Submit"/>
      </form></p>

      <!-- Robyn 10th July - replaced New Search based on what Volume is in the session.
           Found it best to insert quotes for enclosing a string, within a string to use &quot;
           as the enclosing quotes.

           Could try setting a variable and see how this goes.

           <p align="left"><a class="small" href="xxx-query-styles.html">New Search</a></p>
      -->
      <xsl:if test= "/page/request/session/volslist = &quot;NOT IN (''lichenchecklist'', ''49'', ''50'')&quot;" >

        <p align="left"><a class="small" href="main-query-styles.html">New Search</a></p>
      </xsl:if>

      <xsl:if test= "/page/request/session/volslist = &quot;= ''49''&quot;" >

        <p align="left"><a class="small" href="vol49-query-styles.html">New Search</a></p>
      </xsl:if>

      <xsl:if test= "/page/request/session/volslist = &quot;= ''50''&quot;" >

        <p align="left"><a class="small" href="vol50-query-styles.html">New Search</a></p>
      </xsl:if>

      <p align="left">&nbsp;</p>

      <!-- Robyn 29th July Removed the links down the side of the page.
      <p align="left">&nbsp;</p>
      <p align="left"><a class="smaller" href="http://www.deh.gov.au/biodiversity/abrs/about/publications/glossaries/index.html">ABRS Glossaries</a></p>
      <p align="left"><a class="smaller" href="http://www.anbg.gov.au/cgi-bin/apni">APNI</a></p>
      <p align="left"><a class="smaller" href="http://www.deh.gov.au/biodiversity/abrs/flora/links.html#amani">AMANI</a></p>
      <p align="left"><a class="smaller" href="http://plantnet.rbgsyd.gov.au/PlantNet/fwalgae/index.htm">Freshwater
      Algae</a></p>

      <p align="left"><a class="smaller" href="http://www.rbgmelb.org.au/fungi/">Fungi</a></p>
      <p align="left"><a class="smaller" href="http://www.anbg.gov.au/abrs/lichenlist/introduction.html">Lichens</a></p>
      <p align="left"><a class="smaller" href="http://www.anbg.gov.au/win">What's its Name?</a></p>
      <p><a href="http://www.deh.gov.au/biodiversity/abrs/index.html"><img src="images/abrsgrn_transp.gif" width="56" height="92" border="0" vspace="0" hspace="0"/></a></p>
      <p><a href="http://www.deh.gov.au/biodiversity/abrs/flora/index.html"><img width="56" height="60" border="0" vspace="0" hspace="0" src="images/abif_small_transp.gif"/></a></p>
      <p>&nbsp;</p>
      -->

    </td>

    <!--<td width="88%" height="476" valign="top">-->
    <td width="92%" valign="top">
    <div align="center">
    <h1>Flora of Australia Online</h1>
    
    <!-- header //-->
      
    <xsl:if test="$OutputFormat='HTML'">
      format
    </xsl:if>
      
    <xsl:for-each select="ROWSET/ROW">

      <xsl:if test="TITLE and not(TITLE[@NULL])">
        <h3 class="title">
          <!-- <xsl:value-of select="./SEQ" disable-output-escaping="yes"/>
               .&nbsp; -->

          <xsl:choose>
            <xsl:when test="RANK='group' or RANK='subgroup'">
              <i>
                <xsl:value-of select="TITLE" disable-output-escaping="yes"/>
                <xsl:if test="GENUS[not(@NULL)]">
                  <xsl:text> (</xsl:text>
                  <xsl:value-of select="GENUS[not(@NULL)]"/>
                  <xsl:text>)</xsl:text>
                </xsl:if>
              </i>
            </xsl:when>

            <xsl:when test="RANK !='var.' and RANK !='f.' and RANK !='subsp.' and RANK !='sp.'">
              <xsl:value-of select="TITLE" disable-output-escaping="yes"/>
            </xsl:when>
          </xsl:choose>
        </h3>
      </xsl:if>

      <!-- Robyn Lawrence 23rd December 2003, only do the higher ranked contributors. -->
      <!-- <xsl:if test="CONTRIBUTORS"> -->
      <xsl:if test="CONTRIBUTORS and RANK !='var.' and RANK !='f.' and RANK !='subsp.' 
      and RANK !='sp.'">
        <p class="contributor">
          <xsl:apply-templates select="CONTRIBUTORS/CONTRIBUTORS_ITEM"/>
        </p>
      </xsl:if>

      <!-- Robyn 6th August 2003, only print the Name from standardDisplayName,
      if the rank is not amongst the higher taxons.  These higher taxa will have a 
      title which would have already been printed with the TITLE.  
      These higher Taxons would not have etymology or commonnames, 
      so it is OK to include these in the test.
      -->

      <xsl:if test="not( RANK = 'kingdom' or RANK = 'division' or RANK = 'order'
                         or RANK = 'class' )
                    and ( NAME and not(NAME[@NULL]))">

        <p class="name">

          <xsl:call-template name="standardDisplayName"/>
       
          <xsl:if test="$displayall">
            <xsl:if test="ETYMOLOGY and not(ETYMOLOGY[@NULL])">
              <xsl:text>;&nbsp;</xsl:text>
              <xsl:value-of select="ETYMOLOGY" disable-output-escaping="yes"/>
            </xsl:if>
          </xsl:if>

          <xsl:if test="$commonnames">
            <br/>
            <i><xsl:value-of select="COMMONNAME" disable-output-escaping="yes"/></i>
          </xsl:if>
        </p>
      
      </xsl:if>

      <!-- names list link -->
      <!-- Robyn 10th July 2003, changed to nameslist.xsql for the moment -->
      <p class="nameslistlink">
        <xsl:element name="a">
          <xsl:attribute name="href">
            <xsl:text>nameslist.xsql?pnid=</xsl:text>
            <xsl:value-of select="PNID"/>
          </xsl:attribute>
          <xsl:text>Hierarchical Names List Entry</xsl:text>
        </xsl:element>
      </p>

      <xsl:if test="TYPIFICATION and $typification and not(TYPIFICATION[@NULL])">
        <p class="typification">
          <xsl:value-of select="TYPIFICATION" disable-output-escaping="yes"/>
        </p>
      </xsl:if>

      <!-- R. Lawrence 23rd August 2004.  Added a sort for Synonyms.  Rather than doing it 
      in the database.  -->
      <!-- have to display syn kind = 'nom' if either synonyms or typification selected -->
      <xsl:if test="$synonymy or $typification">
        <xsl:apply-templates select="SYNONYMS/SYNONYMS_ITEM[SYNKIND='nom']">
          <xsl:sort data-type="number" select="SYNSEQ"/>
        </xsl:apply-templates>
      </xsl:if>

      <!-- R. Lawrence 23rd August 2004.  Added a sort for Synonyms.  Rather than doing it 
      in the database.  -->

      <xsl:if test="$synonymy">
        <xsl:apply-templates select="SYNONYMS/SYNONYMS_ITEM[SYNKIND='tax']">
          <xsl:sort data-type="number" select="SYNSEQ"/>
        </xsl:apply-templates>

        <xsl:apply-templates select="SYNONYMS/SYNONYMS_ITEM[SYNKIND='misapp']">
          <xsl:sort data-type="number" select="SYNSEQ"/>
        </xsl:apply-templates>

      </xsl:if>
          
      <xsl:if test="$illrefs">
        <xsl:if test="ILLUSTRATIONS and not(ILLUSTRATIONS[@NULL])">
          <p class="illustrations">
            <xsl:value-of select="ILLUSTRATIONS" disable-output-escaping="yes"/>
          </p>
        </xsl:if>
      </xsl:if>
          
      <xsl:if test="$notes">
        <xsl:apply-templates select="NOTES/NOTES_ITEM[NOTEKIND='prenote']">
          <!-- xsl:apply-templates select="NOTES/NOTES_ITEM[NOTEKIND='prenote']" -->
          <xsl:sort data-type="number" select="NOTESEQ"/>
        </xsl:apply-templates>
      </xsl:if>
          
      <xsl:if test="DESCRIPTION|CHROMOSOME|COMMONNAME|IMAGES/IMAGES_ITEM[IMGKIND='fig'] and ($description or $chromosomes or $images)">
        <p class="standard">
          <xsl:if test="$description and not(DESCRIPTION[@NULL])">
            <xsl:value-of select="DESCRIPTION" disable-output-escaping="yes"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>
          <xsl:if test="$chromosomes and not(CHROMOSOME[@NULL])">
            <xsl:value-of select="CHROMOSOME" disable-output-escaping="yes"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>

          <xsl:if test="$images and IMAGES/IMAGES_ITEM[IMGKIND='fig']">
            <xsl:text>Fig.</xsl:text>
            <xsl:apply-templates select="IMAGES/IMAGES_ITEM[IMGKIND='fig']">
              <xsl:sort data-type="number" select="IMGSEQ"/>
            </xsl:apply-templates>
          </xsl:if>
        </p>
      </xsl:if>
          
          
      <xsl:if test="DISTRIBUTIONS[DISTRIBUTIONS_ITEM]|HABITAT|PHENOLOGY|IMAGES/IMAGES_ITEM[IMGKIND='map'] and ($distribution or $habitat or $images or $phenology)">
        <p class="standard">
          <xsl:if test="$distribution and DISTRIBUTIONS[DISTRIBUTIONS_ITEM]">
            <xsl:for-each select="DISTRIBUTIONS">
              <xsl:for-each select="DISTRIBUTIONS_ITEM">
                <xsl:sort data-type="number" select="DIST_SEQ"/>
                <xsl:value-of select="DIST_TEXT" disable-output-escaping="yes"/>
                <xsl:if test="position() != last()">
                  <br/><br/>
                </xsl:if>
              </xsl:for-each>
            </xsl:for-each>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>

          <xsl:if test="HABITAT and not(HABITAT[@NULL]) and $habitat">
            <xsl:value-of select="HABITAT" disable-output-escaping="yes"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>

          <xsl:if test="not(PHENOLOGY[@NULL]) and $phenology">
            <xsl:value-of select="PHENOLOGY" disable-output-escaping="yes"/>
            <xsl:text>&nbsp;</xsl:text>
          </xsl:if>
        
          <xsl:if test="$images and IMAGES/IMAGES_ITEM[IMGKIND='map']">
            <xsl:text>Map</xsl:text>
            <!-- bit of convoluted stuff here. we need to create a
                 variable, to pass in a map name as a parameter, as if
                 we try to construct the map text in the with-param
                 the context would have changed so we couldn't as
                 easily get to the stuff we want. -->
            <xsl:variable name="maptext">
              <xsl:choose>
                <xsl:when test="RANK = 'sp.'">
                  <xsl:value-of select="GENUS"/>    
                </xsl:when>
                <xsl:when test="RANK = 'subsp.' or RANK = 'var.' or RANK = 'f.'">
                  <xsl:value-of select="PARENT"/>
                  <xsl:text> </xsl:text>
                  <xsl:value-of select="RANK"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="PARENT"/>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text> </xsl:text>
              <xsl:value-of select="NAME"/>
            </xsl:variable>
            <xsl:apply-templates select="IMAGES/IMAGES_ITEM[IMGKIND='map']">
              <xsl:with-param name="maptext">
                <xsl:value-of select="$maptext"/>
              </xsl:with-param>
              <xsl:sort data-type="number" select="IMGSEQ"/>
            </xsl:apply-templates>
          </xsl:if>
        </p>
      </xsl:if>
          
      <xsl:if test="$specimens and SPECIMENS and not(SPECIMENS[@NULL])">
        <p class="specimens">
          <xsl:value-of select="SPECIMENS" disable-output-escaping="yes"/>
        </p>
      </xsl:if>
          
      <xsl:if test="CONSERVATION and not(CONSERVATION[@NULL]) and $conservationstatus">
        <p class="standard">
          <xsl:value-of select="CONSERVATION" disable-output-escaping="yes"/>
        </p>
      </xsl:if>
          
      <xsl:if test="$notes">
        <xsl:apply-templates select="NOTES/NOTES_ITEM[NOTEKIND != 'prenote']">
          <xsl:sort data-type="number" select="NOTESEQ"/>
        </xsl:apply-templates>
      </xsl:if>
          
      <xsl:if test="REFERENCE and not(REFERENCE[@NULL]) and $taxrefs">
        <p class="reference">
          <xsl:value-of select="REFERENCE" disable-output-escaping="yes"/>
        </p>
      </xsl:if>

      <!-- Robyn Lawrence 23rd December 2003, lower ranked contributors are left aligned. -->
      <xsl:if test="CONTRIBUTORS
      and ( RANK ='var.' or RANK ='f.' or RANK ='subsp.' or RANK ='sp.')">
        <p class="contributor_sp">
          <xsl:apply-templates select="CONTRIBUTORS/CONTRIBUTORS_ITEM"/>
        </p>
      </xsl:if>
          
      <xsl:if test="$keys">
        <xsl:for-each select="KEYS/KEYS_ITEM">
          <xsl:if test="KHEAD and not(KHEAD[@NULL])">
            <h2 class="key">
              <xsl:value-of select="KHEAD" disable-output-escaping="yes"/>
            </h2>
          </xsl:if>

          <xsl:if test="KTITLE and not(KTITLE[@NULL])">
            <h2 class="key">
              <xsl:value-of select="KTITLE" disable-output-escaping="yes"/>
            </h2>
          </xsl:if>

          <xsl:if test="KEY_CONTRIBUTORS">
            <p class="contributor">
              <xsl:apply-templates select="KEY_CONTRIBUTORS/KEY_CONTRIBUTORS_ITEM"/>
            </p>
          </xsl:if>
            
          <xsl:if test="KNOTE_FRONT and not(KNOTE_FRONT[@NULL])">
            <p class="standard">
              <xsl:value-of select="KNOTE_FRONT" disable-output-escaping="yes"/>
            </p>
          </xsl:if>
            

          <p class="key">
            <table class="key" width="100%" >
              <xsl:for-each select="KEY_ITEMS/KEY_ITEMS_ITEM">
                <!-- try to ensure that "n:" comes after "n", but that they both
                     appear before "n+1" and "n+1:" -->
                <xsl:sort data-type="number" select="translate(KPAIR, ':', '')"/>
                <xsl:sort data-type="number" select="string-length(KPAIR)"/>
                <tr>
                  <xsl:variable name="key">
                    <xsl:value-of select="KPAIR"/>
                    <xsl:if test="KCOUPLET=1">:</xsl:if>
                  </xsl:variable>

                  <!-- R.Lawrence 20th August 2004.  Fudge to not display Volume '0'
                  Key Pairs.  -->

                  <xsl:if test="../../../../VOLUME !='0'" >
                    <td width="5%" valign="top">
                      <xsl:if test="$key">
                        <a name="{KEY_ID}_{$key}"/>
                        <xsl:value-of select="$key"/>
                      </xsl:if>
                    </td>
                  </xsl:if>

                  <td class="key" valign="top">
                    <xsl:value-of select="KTEXT" disable-output-escaping="yes"/>
                  </td>
                  <td valign="bottom">
                    <p class="key-leaf">

                      <!-- Robyn Lawrence 12th January 2004.  Moved
                       ksymbol outside the a tag.  -->
                      <xsl:value-of select="KSYMBOL[not(@NULL)]"/>

                      <a>
                        <xsl:attribute name="href">
                          <xsl:choose>
                            <xsl:when test="not(KTO[@NULL])">#<xsl:value-of select="KEY_ID"/>_<xsl:value-of select="KTO" disable-output-escaping="yes"/></xsl:when>
                            <xsl:when test="KLINK[not(@NULL)]">
                              <xsl:text>stddisplay.xsql?pnid=</xsl:text>
                              <xsl:value-of select="KLINK"/>
                            </xsl:when>
                            <xsl:when test="not(KTAXON[@NULL])">
                              <xsl:text>stddisplay.xsql?sn_infspnm=</xsl:text>
                              <xsl:value-of select="KTAXON" disable-output-escaping="yes"/>
                              <xsl:text>&amp;sn_infsprnk=</xsl:text>
                              <xsl:value-of select="KRANK" disable-output-escaping="yes"/>
                              <xsl:text>&amp;sn_fam=</xsl:text>
                              <xsl:value-of select="ancestor::ROW/SN_FAMILY" disable-output-escaping="yes"/>
                              <xsl:text>&amp;sn_gen=</xsl:text>
                              <xsl:value-of select="ancestor::ROW/SN_GENUS" disable-output-escaping="yes"/>
                              <xsl:text>&amp;sn_sp=</xsl:text>
                              <xsl:value-of select="ancestor::ROW/SN_SPECIES" disable-output-escaping="yes"/>
                            </xsl:when>
                          </xsl:choose>
                        </xsl:attribute>
                        <xsl:value-of select="KTO" disable-output-escaping="yes"/>
                        <xsl:choose>
                          <xsl:when test="KNAME_KIND = 'hybrid_formula'">
                            <xsl:call-template name="strip-genus-from-hybrid-name">
                              <xsl:with-param name="genus" select="../../../../GENUS"/>
                              <xsl:with-param name="hybrid-name">
                                <xsl:value-of select="KHYBRID" disable-output-escaping="yes"/>
                              </xsl:with-param>
                            </xsl:call-template>
                            <xsl:text> &#215; </xsl:text>
                            <xsl:call-template name="strip-genus-from-hybrid-name">
                              <xsl:with-param name="genus" select="../../../../GENUS"/>
                              <xsl:with-param name="hybrid-name">
                                <xsl:value-of select="KHYBRID2" disable-output-escaping="yes"/>
                              </xsl:with-param>
                            </xsl:call-template>
                          </xsl:when>
                          <xsl:when test="KNAME_KIND = 'hybrid_formula_?'">
                            <xsl:call-template name="strip-genus-from-hybrid-name">
                              <xsl:with-param name="genus" select="../../../../GENUS"/>
                              <xsl:with-param name="hybrid-name">
                                <xsl:value-of select="KHYBRID" disable-output-escaping="yes"/>
                              </xsl:with-param>
                            </xsl:call-template>
                            <xsl:text> &#215; ?</xsl:text>
                            <xsl:call-template name="strip-genus-from-hybrid-name">
                              <xsl:with-param name="genus" select="../../../../GENUS"/>
                              <xsl:with-param name="hybrid-name">
                                <xsl:value-of select="KHYBRID2[not(@NULL)]" disable-output-escaping="yes"/>
                              </xsl:with-param>
                            </xsl:call-template>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:if test="KNAME_KIND = 'named_hybrid'">
                              <xsl:text>&#215;&nbsp;</xsl:text>
                            </xsl:if>
                            <xsl:if test="KRANK = 'subsp.' or KRANK = 'var.' or KRANK = 'f.' or KRANK='subg.' or KRANK = 'sect.' or KRANK = 'trib.' or KRANK = 'subtrib.' or KRANK = 'subsect.' or KRANK = 'ser.' or KRANK = 'subser.'">
                              <span class="key-rank">
                                <xsl:value-of select="KRANK"/>
                                <xsl:text>&nbsp;</xsl:text>
                              </span>
                            </xsl:if>
                            <!-- <xsl:value-of select="KSYMBOL[not(@NULL)]"/> -->
                            <xsl:value-of select="KTAXON" disable-output-escaping="yes"/>


                            <!-- Robyn 8th January 2004 - testing blanking
                            out the Group and Subgroup if ktaxon is NULL -->
                            <xsl:if test="not(KTAXON[@NULL]) and KRANK = 'group'">
                              <span class="key-rank">
                                <xsl:text>&nbsp;Group</xsl:text>
                              </span>
                            </xsl:if>

                            <xsl:if test="not(KTAXON[@NULL]) and KRANK = 'subgroup'">
                              <span class="key-rank">
                                <xsl:text>&nbsp;Subgroup</xsl:text>
                              </span>
                            </xsl:if>

                          </xsl:otherwise>
                        </xsl:choose>
                      </a>
                      <!-- Robyn 8th January 2004 - moved so kextra
                      not part of the hyperlink. -->
                      <xsl:if test="KEXTRA[not(@NULL)]">
                        <xsl:text> </xsl:text>
                        <xsl:value-of select="KEXTRA" disable-output-escaping="yes"/>
                      </xsl:if>
                    </p>
                  </td>
                </tr>
              </xsl:for-each>
            </table>
          </p>
            
          <xsl:if test="KNOTE_END and not(KNOTE_END[@NULL])">
            <p class="standard">
              <xsl:value-of select="KNOTE_END" disable-output-escaping="yes"/>
            </p>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
    </xsl:for-each>
        
    <!-- tail // -->
  </div>
</td>
<td rowspan="2" height="231" width="4%">&nbsp;</td>
</tr>
<tr>
  <td width="88%" height="2">
      <div align="center">
        <!-- use Muenchian Technique to get unique source values -->
        <xsl:for-each select=".//SOURCE[generate-id(.) = generate-id(key('source_key', .))]">
          <p class="source"><xsl:value-of select="." disable-output-escaping="yes"/></p>
        </xsl:for-each>
      </div>
    </td>
  </tr>
</table>
</xsl:template>

</xsl:stylesheet>
